[Lldb-commits] [lldb] [lldb][test] Narrow enum test xfail to clang < 19.0 (PR #98616)

David Spickett via lldb-commits lldb-commits at lists.llvm.org
Fri Jul 12 03:46:34 PDT 2024


https://github.com/DavidSpickett created https://github.com/llvm/llvm-project/pull/98616

Sice #98335 clang adds DW_AT_type, unless strict DWARF is requested.

>From 6b21c9e4dc4735dbd1be8c1b125e35c3ee01bbf7 Mon Sep 17 00:00:00 2001
From: David Spickett <david.spickett at linaro.org>
Date: Fri, 12 Jul 2024 10:29:31 +0000
Subject: [PATCH] [lldb][test] Narrow enum test xfail to clang < 19.0

Sice #98335 clang adds DW_AT_type, unless strict DWARF is
requested.
---
 .../expression/bitfield_enums/TestBitfieldEnums.py        | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/lldb/test/API/commands/expression/bitfield_enums/TestBitfieldEnums.py b/lldb/test/API/commands/expression/bitfield_enums/TestBitfieldEnums.py
index dbe9b9241a9ac..05db4075870b8 100644
--- a/lldb/test/API/commands/expression/bitfield_enums/TestBitfieldEnums.py
+++ b/lldb/test/API/commands/expression/bitfield_enums/TestBitfieldEnums.py
@@ -10,9 +10,11 @@
 
 
 class TestBitfieldEnum(TestBase):
-    # clang's DWARF v2 output is missing DW_AT_type which causes unsigned_max to
-    # appear as -1 instead of the "max" enumerator, whose value is 3.
-    @skipIf(dwarf_version=["<", "3"], compiler="clang")
+    # Prior to clang-19, clang's DWARF v2 is missing missing DW_AT_type which
+    # causes unsigned_max to appear as -1 instead of the "max" enumerator, whose
+    # value is 3. From 19 onward, DW_AT_type is added as long as strict DWARF
+    # is not enabled.
+    @skipIf(dwarf_version=["<", "3"], compiler="clang", compiler_version=["<", "19.0"])
     def test_bitfield_enums(self):
         self.build()
 



More information about the lldb-commits mailing list